@@ -290,9 +290,9 @@ def serialize_link(ctx, document, elem, root):
                     _text = children[-1].tail or u''
 
                     children[-1].tail = u'{}{}'.format(_text, el.value())
-
-    if elem.rid in document.relationships:
-        _a.set('href', document.relationships[elem.rid].get('target', ''))
+   
+    if elem.rid in document.relationships[ctx.options['relationship']]:
+        _a.set('href', document.relationships[ctx.options['relationship']][elem.rid].get('target', ''))
 
     fire_hooks(ctx, document, elem, _a, ctx.get_hook('a'))
 
@@ -308,8 +308,8 @@ def serialize_image(ctx, document, elem, root):
     _img = etree.SubElement(root, 'img')
     # make path configurable
 
-    if elem.rid in document.relationships:
-        img_src = document.relationships[elem.rid].get('target', '')
+    if elem.rid in document.relationships[ctx.options['relationship']]:
+        img_src = document.relationships[ctx.options['relationship']][elem.rid].get('target', '')
         img_name, img_extension = os.path.splitext(img_src)
 
         _img.set('src', 'static/{}{}'.format(elem.rid, img_extension))
@@ -550,7 +550,6 @@ def serialize_paragraph(ctx, document, par, root, embed=True):
     if style:
         max_font_size = _get_font_size(document, style)
 
-        
     for el in par.elements:
         _serializer =  ctx.get_serializer(el)
 
@@ -560,6 +559,12 @@ def serialize_paragraph(ctx, document, par, root, embed=True):
         if isinstance(el, doc.Text):
             children = list(elem)
             _text_style = get_style_css(ctx, el)
+            _text_class = el.rpr.get('style', '').lower()
+
+            if _text_class == '':
+                __s = get_style(document, par)
+                if __s is not None:
+                    _text_class = get_style_name(__s).lower()
 
             if get_style_fontsize(el) > max_font_size:
                 max_font_size = get_style_fontsize(el)
@@ -598,10 +603,15 @@ def serialize_paragraph(ctx, document, par, root, embed=True):
             else:
                 new_element = etree.Element('span')
                 new_element.text = el.value()
+                if ctx.options['embed_styles']:
+                    try:
+                        new_element.set('class', _text_class)
+                    except:
+                        pass
 
                 for comment_id in ctx.opened_comments:
-                    document.comments[comment_id].text += ' ' + el.value()
-
+                    if comment_id in document.comments:
+                        document.comments[comment_id].text += ' ' + el.value()
 
             if ctx.options['embed_styles']:
                 if _text_style != '' and _style != _text_style:
@@ -614,34 +624,43 @@ def serialize_paragraph(ctx, document, par, root, embed=True):
 
             was_inserted = False
 
-
             if len(children) > 0:
                 _child_style = children[-1].get('style') or ''
+                _child_class = children[-1].get('class', '')
 
-                if new_element.tag == children[-1].tag and (_text_style == _child_style or _child_style == '') and children[-1].tail is None:
+                if new_element.tag == children[-1].tag and ((_text_class == _child_class or _child_class == '') and (_text_style == _child_style or _child_style == '')) and children[-1].tail is None:
                     txt = children[-1].text or ''
                     txt2 = new_element.text or ''
                     children[-1].text = u'{}{}'.format(txt, txt2)  
                     was_inserted = True
 
                 if not was_inserted:
-#                    if _style == '' and _text_style == '' and new_element.tag == 'span':
-                    if _style == _text_style  and new_element.tag == 'span':
-
+                    if _style == _text_style  and new_element.tag == 'span' and (_text_class == _child_class or _child_class == ''):
                         _e = children[-1]
 
                         txt = _e.tail or ''
                         _e.tail = u'{}{}'.format(txt, new_element.text)
                         was_inserted = True
+  
+                    if not was_inserted and new_element.tag == 'span' and (_text_class != _child_class):
+                        _e = children[-1]
+                        txt = _e.tail or ''
+                        _e.tail = u'{}{}'.format(txt, new_element.text)
+                        was_inserted = True       
 
             if not was_inserted:
-#                if _style == '' and _text_style == '' and new_element.tag == 'span':
-                if _style ==  _text_style  and new_element.tag == 'span':
+                _child_class = new_element.get('class', '')
+                try:
+                    _child_class = children[-1].get('class', '')
+                except:
+                    _child_class = ''
 
+                if _style ==  _text_style  and new_element.tag == 'span' and (_text_class == _child_class):
                     txt = elem.text or ''
                     elem.text = u'{}{}'.format(txt, new_element.text)
                 else:
-                    elem.append(new_element)
+                    if new_element.text != u'':
+                        elem.append(new_element)
     
     if not par.is_dropcap() and par.ilvl == None:
         if style:
@@ -973,7 +992,7 @@ class HeaderContext:
                 except:
                     pass
 
-            sorted_list_of_sizes = list(collections.OrderedDict(sorted(list_of_sizes.iteritems(), key=lambda t: t[0])))
+            sorted_list_of_sizes = list(collections.OrderedDict(sorted(six.iteritems(list_of_sizes), key=lambda t: t[0])))
             font_size_to_check = font_size
 
             if len(sorted_list_of_sizes) > 0:
@@ -1036,7 +1055,8 @@ DEFAULT_OPTIONS = {
     'embed_fontsize': True,
     'smarttag_span': False,
     'comment_span': False,
-    'pretty_print': True
+    'pretty_print': True,
+    'relationship': 'document'
 }
 
 
